@@ -4,7 +4,7 @@ library(httr)
 library(jsonlite)
 library(stringr)
 
-rbitlyApi("0906523ec6a8c78b33f9310e84e7a5c81e500909")
+options(Bit.ly = "0906523ec6a8c78b33f9310e84e7a5c81e500909")
 
 context("Domains")
 
